@@ -7,6 +7,8 @@ use testing::{examples, retry};
 
 const TIMEOUT: &str = "60";
 
+#[allow(unknown_lints)]
+#[allow(nonreentrant_function_in_test)]
 #[test]
 fn fuzz_foo_qwerty() {
     // smoelius: When `bincode` is enabled, `cargo-afl` fails because "the program crashed with one
@@ -18,6 +20,8 @@ fn fuzz_foo_qwerty() {
     };
 }
 
+#[allow(unknown_lints)]
+#[allow(nonreentrant_function_in_test)]
 #[test]
 fn fuzz_bar_asdfgh() {
     fuzz("test_bar_asdfgh", 0);
@@ -33,6 +37,9 @@ fn fuzz(test: &str, code: i32) {
 
     let corpus = corpus_directory_from_target("generic", "target");
 
+    // smoelius: This call to `remove_dir_all` is protected by the mutex above.
+    #[allow(unknown_lints)]
+    #[allow(nonreentrant_function_in_test)]
     remove_dir_all(&corpus).unwrap_or_default();
 
     examples::test("generic", test).unwrap().assert().success();
